@@ -275,23 +275,16 @@ static const char *closure_use_flags[] = {
 	NULL
 };
 
-#define AST_VISIBILITY_FLAGS \
-	AST_FLAG(MODIFIER_PUBLIC), \
-	AST_FLAG(MODIFIER_PROTECTED), \
-	AST_FLAG(MODIFIER_PRIVATE)
 
 #define AST_MODIFIER_FLAGS \
-	AST_VISIBILITY_FLAGS, \
+	AST_FLAG(MODIFIER_PUBLIC), \
+	AST_FLAG(MODIFIER_PROTECTED), \
+	AST_FLAG(MODIFIER_PRIVATE), \
 	AST_FLAG(MODIFIER_STATIC), \
 	AST_FLAG(MODIFIER_ABSTRACT), \
 	AST_FLAG(MODIFIER_FINAL), \
 	AST_FLAG(MODIFIER_READONLY)
 
-static const char *visibility_flags[] = {
-	AST_VISIBILITY_FLAGS,
-	NULL
-};
-
 static const char *modifier_flags[] = {
 	AST_MODIFIER_FLAGS,
 	NULL
@@ -471,6 +464,12 @@ static inline zend_bool ast_is_name(zend_ast *ast, zend_ast *parent, uint32_t i)
 			;
 	}
 
+#if PHP_VERSION_ID >= 80300
+	if (i == 2) {
+		return parent->kind == ZEND_AST_CLASS_CONST_GROUP;
+	}
+#endif
+
 	if (i == 1) {
 		return parent->kind == ZEND_AST_INSTANCEOF;
 	}
@@ -511,6 +510,11 @@ static inline zend_bool ast_is_type(zend_ast *ast, zend_ast *parent, uint32_t i)
 #endif
 			;
 	}
+#if PHP_VERSION_ID >= 80300
+	if (i == 2) {
+		return parent->kind == ZEND_AST_CLASS_CONST_GROUP;
+	}
+#endif
 	if (i == 3) {
 		return parent->kind == ZEND_AST_CLOSURE || parent->kind == ZEND_AST_FUNC_DECL
 #if PHP_VERSION_ID >= 70400
@@ -768,6 +772,13 @@ static void ast_fill_children_ht(HashTable *ht, zend_ast *ast, ast_state_info_t
 			}
 		}
 #endif
+#if PHP_VERSION_ID >= 80300
+		if (ast_kind == ZEND_AST_CLASS_CONST_GROUP && i == 2) {
+			if (state->version < 100)  {
+				continue;
+			}
+		}
+#endif
 #endif
 		if (ast_is_name(child, ast, i)) {
 			ast_name_to_zval(child, ast, &child_zv, i, state);
@@ -857,6 +868,15 @@ static void ast_fill_children_ht(HashTable *ht, zend_ast *ast, ast_state_info_t
 				zend_hash_add_new(ht, AST_STR(str_type), &tmp);
 			}
 		}
+#endif
+#if PHP_VERSION_ID < 80300
+		if (ast_kind == ZEND_AST_CLASS_CONST_GROUP) {
+			if (state->version >= 100) {
+				zval tmp;
+				ZVAL_NULL(&tmp);
+				zend_hash_add_new(ht, AST_STR(str_type), &tmp);
+			}
+		}
 #endif
 		ZVAL_LONG(&id_zval, state->declIdCounter);
 		state->declIdCounter++;
@@ -1071,14 +1091,14 @@ static void ast_to_zval(zval *zv, zend_ast *ast, ast_state_info_t *state) {
 #endif
 }
 
-static const zend_long versions[] = {50, 60, 70, 80, 85, 90};
+static const zend_long versions[] = {50, 60, 70, 80, 85, 90, 100};
 static const size_t versions_count = sizeof(versions)/sizeof(versions[0]);
 
 static inline zend_bool ast_version_deprecated(zend_long version) {
 	return version < 70;
 }
 
-static zend_string *ast_version_info() {
+static zend_string *ast_version_info(void) {
 	smart_str str = {0};
 	size_t i;
 
